@@ -3,4 +3,4 @@ from . import execute_from_commandline
 
 
 if __name__ == '__main__':
-    execute_from_commandline(sys.argv)
+    execute_from_commandline(sys.argv[1:])
